<?php

class ActivateWizard
{
	// dialplan variables
	var $fromDirection = 'fromDirection';
	var $toDirection   = 'toDirection'  ;
	var $fromId	   = 'fromId'	    ;
	var $toId	   = 'toId'	    ;
	var $dest	   = 'dest'	    ;
	var $newDest	   = 'newDest'	    ;
	var $src	   = 'src'	    ;
	var $newSrc	   = 'newSrc'	    ;

	var $dialplan_rules = array()	; 
	var $trunk_config   = "sip_ppi_user_setting=\${new_source},from_sip_src_setting=ppi_user";

	// class variables
	var $network_wizard   = NULL;
	var $scenarios_wizard = NULL;
	var $sip_wizard	      = NULL;
	var $pstn_wizard      = NULL;

	// settings
	var $scenario_settings = '';
	var $sip_settings      = '';
	var $pstn_settings     = '';
	var $network_settings  = '';

	// file
	var $file_conf 	= '/tmp/wizard-voip.conf';

function __construct($ba = NULL, $wizard_cfg = array())
{
	if (count($wizard_cfg) == 0 || is_null($ba))
	{
		return;
	}

	// get the previuous class
	require_once('./modules/Wizard/network_wizard_popup.php');	
	$this -> network_wizard = new NetworkWizard(false);

	require_once('./modules/Wizard/scenarios_wizard_popup.php');	
	$this -> scenarios_wizard = new ScenariosWizard(false);

	require_once('./modules/Wizard/sip_wizard_popup.php');	
	$this -> sip_wizard = new SipWizard(false);

	require_once('./modules/Wizard/pstn_wizard_popup.php');	
	$this -> pstn_wizard = new PstnWizard(false);

	if (isset($wizard_cfg['Dialplan']))
	{
		unset($wizard_cfg['Dialplan']);
	}

	// getting the scenario
	$this -> scenario_settings = key($wizard_cfg['Scenarios']); 	

	// setting up Network Configuration
	$this -> network_settings = $this -> network_wizard -> organize_settings($wizard_cfg['Network']);

	// setting up Sip Configuration
	$this -> sip_settings = $this -> sip_wizard -> organize_settings($ba, $wizard_cfg['Sip']);

	// setting up Pstn Configuration
	$this -> pstn_settings = $this -> pstn_wizard -> organize_settings($wizard_cfg['Pstn']);

	// set the Dialplan rules
	$this -> dialplan_rules = $this -> _set_dialplan_rules($this -> scenario, $this -> sip_settings, $this -> pstn_settings);

	// generate config file
	$this -> _save_config_file($this -> scenario, $this -> network_settings, $this -> sip_settings, $this -> pstn_settings, $this -> dialplan_rules);
}

// private 
function _set_dialplan_rules ($scenario, $sip_settings, $pstn_settings)
{
	if (strcmp($scenario, 'Pbx') == 0)
	{ 
		$sip_settings['trunk_config'] = $this -> trunk_config;
		return $this -> _set_pbx_dialplan_rules($sip_settings, $pstn_settings);
	}

	return $this -> _set_gateway_dialplan_rules($sip_settings, $pstn_settings);
}

function _save_config_file ($scenario, $network_settings, $sip_settings, $pstn_settings, $dialplan_rules)
{
	// scenario
	$wizard_str = "Scenario=". $scenario ."\n\n";

	$array_settings = array('Network' => $network_settings, 'Sip' => $sip_settings, 'Pstn' => $pstn_settings, 'Dialplan' => $dialplan_rules);

	foreach ($array_settings as $type => $settings)
	{
		$wizard_str .= "[$type]\n";
		foreach ($settings as $parameter => $value)
		{
			$wizard_str .= "$parameter=$value\n";
		}
		$wizard_str .= "\n";
	}

	$fp = fopen($this -> file_conf, "w+");
	fputs($fp, html_entity_decode($wizard_str));
	fclose($fp);	
}

function _set_gateway_dialplan_rules ($sip_settings, $pstn_settings)
{
	$dialplan_rules = array($this -> dest => '(.*)', $this -> newDest => "\\1", $this -> src => '(.*)', $this -> newSrc => "\\1");

	// Init SIP input
	$name  = $sip_settings['name']   ;

	// Init PSTN input
	$group = $pstn_settings['group'] ;

	// update dialplan rules (SIP => PSTN)
	$dialplan_rules[$this -> fromDirection] = 'sip' ;
	$dialplan_rules[$this -> toDirection]	= 'isdn';

	$dialplan_rules[$this -> fromId] = $name ;
	$dialplan_rules[$this -> toId]	 = $group;

	return $dialplan_rules;
}

function _set_pbx_dialplan_rules ($sip_settings, $pstn_settings)
{
	// TODO: on Voip.php file: if ($_GET['pbx'] == "3CX") { from_sip_src_setting=from_display; } ..... how the $_GET['pbx'] is initialized

	$dialplan_rules = array('dest' => '(.*)', 'newdest' => "\\\\1", 'src' => '(.*)', 'newsrc' => "\\\\1");

	$server_addr = ((isset($sip_settings['PbxPort']) && strlen($sip_settings['PbxPort']) > 0) ? $sip_settings['PbxServer'] .":". $sip_settings['PbxPort'] : $sip_settings['PbxServer']);

	// setting SIP <-> ISDN rules
	if (preg_match("#PRI#", $pstn_settings['type']) || preg_match("#BRI#", $pstn_settings['type']))
	{
	}

	// setting SIP <-> ANALOG rules
	if (preg_match('#FXS#', $pstn_settings['type']) || preg_match("#FXO#", $pstn_settings['type']))
	{
	}

	// setting SIP <-> GSM rules
	if (preg_match("#GSM#", $pstn_settings['type']))
	{
	}

	return $dialplan_rules;
	}

	function _header_section ($setting, $array_titles)
	{
		if (strcmp($setting, 'Configuration') == 0)
		{
			return '';
		}

		ob_start();
	?>
			<p class='text-center h4'><?php echo $array_titles[$setting]['title']; ?></p>
	<?
		return ob_get_clean() . "\n";
	}

	function _get_each_summary_settings ($setting)
	{
		if (strcmp($setting, 'Network') == 0)
		{
			return $this -> network_wizard -> get_summary_settings($array_parameters);
		}

		if (strcmp($setting, 'Scenarios') == 0)
		{
			return $this -> scenarios_wizard -> get_summary_settings($array_parameters);
		}

		if (strcmp($setting, 'Sip') == 0)
		{
			return $this -> sip_wizard -> get_summary_settings($array_parameters);
		}

		if (strcmp($setting, 'Pstn') == 0)
		{
			return $this -> pstn_wizard -> get_summary_settings($array_parameters);
		}
	}

	function _display_dialplan_rules($rules)
	{
		ob_start();
?>
		<p class='text-center h4'><?php echo WIZARD_DIALPLAN_ENTRIES_DIS; ?></p>
		<table class='table table-striped table-bordered'>
			<tr>
				<th>	<?php echo DIALPLAN_FROM_DIRECTION_DIS; ?>	</th>
				<th>	<?php echo DIALPLAN_TO_DIRECTION_DIS; ?>	</th>
				<th>	<?php echo DIALPLAN_FROM_ID_DIS; ?>		</th>
				<th>	<?php echo DIALPLAN_TO_ID_DIS; ?>		</th>
				<th>	<?php echo DIALPLAN_DESTINATION_DIS; ?>		</th>
				<th>	<?php echo DIALPLAN_NEW_DESTINATION_DIS; ?>	</th>
				<th>	<?php echo DIALPLAN_SOURCE_DIS; ?>		</th>
				<th>	<?php echo DIALPLAN_NEW_SOURCE_DIS; ?>		</th>
			</tr>
			<tr> 	<?php // SIP => ISDN ?>
				<td> 	<?php echo $rules[$this -> fromDirection]; ?>	</td>
				<td> 	<?php echo $rules[$this -> toDirection]; ?>	</td>
				<td> 	<?php echo "d:".$rules[$this -> fromId]; ?>	</td>
				<td> 	<?php echo "g:".$rules[$this -> toId]; ?>	</td>
				<td> 	<?php echo $rules[$this -> dest]; ?>		</td>
				<td>	<?php echo $rules[$this -> newDest]; ?>		</td>
				<td> 	<?php echo $rules[$this -> src]; ?>		</td>
				<td> 	<?php echo $rules[$this -> newSrc]; ?>		</td>
			</tr>
			<tr>	<?php // ISDN => SIP ?>
				<td> 	<?php echo $rules[$this -> toDirection]; ?>	</td>
				<td> 	<?php echo $rules[$this -> fromDirection]; ?>	</td>
				<td> 	<?php echo "g:".$rules[$this -> toId]; ?>	</td>
				<td> 	<?php echo "p:".$rules[$this -> fromId]; ?>	</td>
				<td> 	<?php echo $rules[$this -> dest]; ?>		</td>
				<td>	<?php echo $rules[$this -> newDest]; ?>		</td>
				<td> 	<?php echo $rules[$this -> src]; ?>		</td>
				<td> 	<?php echo $rules[$this -> newSrc]; ?>		</td>
			</tr>
		</table>
<?php
		return ob_get_clean();
	}

	// public 
	function get_dialplan_rules ()
	{
		return $this -> dialplan_rules;
	}

	function get_modal_content ()
	{
		// display network
		$html_str  = $this -> network_wizard -> get_summary_settings($this -> network_settings);

		// display scenario
		$html_str .= $this -> scenarios_wizard -> get_summary_settings($this -> scenario_settings);

		// display sip
		$html_str .= $this -> sip_wizard -> get_summary_settings($this -> sip_settings);

		// display pstn
		$html_str .= $this -> pstn_wizard -> get_summary_settings($this -> pstn_settings);

		// display dialplan rules
		$html_str .= $this -> _display_dialplan_rules($this -> dialplan_rules);	

		return $html_str;
	}
}
?>
